summaryrefslogtreecommitdiffstats
path: root/ass_mp.c
diff options
context:
space:
mode:
Diffstat (limited to 'ass_mp.c')
-rw-r--r--ass_mp.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/ass_mp.c b/ass_mp.c
index 0480b546cd..89a0c6eaa1 100644
--- a/ass_mp.c
+++ b/ass_mp.c
@@ -52,7 +52,7 @@ int ass_use_margins = 0;
char *ass_color = NULL;
char *ass_border_color = NULL;
char *ass_styles_file = NULL;
-int ass_hinting = ASS_HINTING_NATIVE + 4; // native hinting for unscaled osd
+int ass_hinting = ASS_HINTING_LIGHT + 4; // light hinting for unscaled osd
#ifdef CONFIG_FONTCONFIG
extern int font_fontconfig;